<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Editatu Inprimakia hartzaileak");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Editatu Inprimakia hartzaileak");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "Formulario Page");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Hartzaile bat baino gehiago ezar ditzakezu komaz emailak bereiztuz.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "hartzaile gordetzen ...");
define('VIEW_FORM_TABLES_HEADING', "Ikusi formularioa taulak");
define('VIEW_FORM_TABLES_BTN', "Ikusi formularioa taulak");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Hautatu Ikusi taulak");
define('VIEW_FORM_TABLES_FILTER_READ', "Iragazi irakurri mezuak");
?>